package net.knarcraft.minecraftserverlauncher.server.servertypes;

import java.io.IOException;

/**
 * Describes a server type
 */
public interface ServerType {

    /**
     * Gets whether this server type is a proxy server
     *
     * @return <p>True if this server type is a proxy server</p>
     */
    boolean isProxy();

    /**
     * Gets the name of the server type
     *
     * @return <p>Server type name</p>
     */
    String getName();

    /**
     * Gets a list of versions available for the server type
     *
     * @return <p>A list of server versions</p>
     */
    String[] getVersions();

    /**
     * Downloads a .jar file for this server type
     *
     * @param folder  <p>The folder to save the downloaded file to</p>
     * @param version <p>The server type version to use</p>
     * @return <p>True if the file exists or was downloaded</p>
     */
    boolean downloadJar(String folder, String version) throws IOException;
}
